@@ -22,6 +22,7 @@ from mypy_boto3_accessanalyzer.paginator import (
     ListAnalyzersPaginator,
     ListArchiveRulesPaginator,
     ListFindingsPaginator,
+    ValidatePolicyPaginator,
 )
 from mypy_boto3_accessanalyzer.type_defs import (
     ConfigurationTypeDef,
@@ -42,6 +43,7 @@ from mypy_boto3_accessanalyzer.type_defs import (
     ListFindingsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     SortCriteriaTypeDef,
+    ValidatePolicyResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -74,7 +76,7 @@ class Exceptions:
 
 class AccessAnalyzerClient:
     """
-    [AccessAnalyzer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [AccessAnalyzer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     """
 
     meta: ClientMeta
@@ -82,12 +84,12 @@ class AccessAnalyzerClient:
 
     def apply_archive_rule(self, analyzerArn: str, ruleName: str, clientToken: str = None) -> None:
         """
-        [Client.apply_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Client.apply_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
         """
 
     def create_access_preview(
@@ -97,7 +99,7 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> CreateAccessPreviewResponseTypeDef:
         """
-        [Client.create_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Client.create_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         """
 
     def create_analyzer(
@@ -109,7 +111,7 @@ class AccessAnalyzerClient:
         tags: Dict[str, str] = None,
     ) -> CreateAnalyzerResponseTypeDef:
         """
-        [Client.create_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Client.create_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         """
 
     def create_archive_rule(
@@ -120,19 +122,19 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> None:
         """
-        [Client.create_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Client.create_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         """
 
     def delete_analyzer(self, analyzerName: str, clientToken: str = None) -> None:
         """
-        [Client.delete_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Client.delete_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         """
 
     def delete_archive_rule(
         self, analyzerName: str, ruleName: str, clientToken: str = None
     ) -> None:
         """
-        [Client.delete_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Client.delete_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         """
 
     def generate_presigned_url(
@@ -143,36 +145,36 @@ class AccessAnalyzerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         """
 
     def get_access_preview(
         self, accessPreviewId: str, analyzerArn: str
     ) -> GetAccessPreviewResponseTypeDef:
         """
-        [Client.get_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Client.get_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         """
 
     def get_analyzed_resource(
         self, analyzerArn: str, resourceArn: str
     ) -> GetAnalyzedResourceResponseTypeDef:
         """
-        [Client.get_analyzed_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Client.get_analyzed_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         """
 
     def get_analyzer(self, analyzerName: str) -> GetAnalyzerResponseTypeDef:
         """
-        [Client.get_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Client.get_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         """
 
     def get_archive_rule(self, analyzerName: str, ruleName: str) -> GetArchiveRuleResponseTypeDef:
         """
-        [Client.get_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Client.get_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         """
 
     def get_finding(self, analyzerArn: str, id: str) -> GetFindingResponseTypeDef:
         """
-        [Client.get_finding documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Client.get_finding documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
         """
 
     def list_access_preview_findings(
@@ -184,14 +186,14 @@ class AccessAnalyzerClient:
         nextToken: str = None,
     ) -> ListAccessPreviewFindingsResponseTypeDef:
         """
-        [Client.list_access_preview_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Client.list_access_preview_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         """
 
     def list_access_previews(
         self, analyzerArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListAccessPreviewsResponseTypeDef:
         """
-        [Client.list_access_previews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Client.list_access_previews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         """
 
     def list_analyzed_resources(
@@ -210,7 +212,7 @@ class AccessAnalyzerClient:
         ] = None,
     ) -> ListAnalyzedResourcesResponseTypeDef:
         """
-        [Client.list_analyzed_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Client.list_analyzed_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         """
 
     def list_analyzers(
@@ -220,14 +222,14 @@ class AccessAnalyzerClient:
         type: Literal["ACCOUNT", "ORGANIZATION"] = None,
     ) -> ListAnalyzersResponseTypeDef:
         """
-        [Client.list_analyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Client.list_analyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         """
 
     def list_archive_rules(
         self, analyzerName: str, maxResults: int = None, nextToken: str = None
     ) -> ListArchiveRulesResponseTypeDef:
         """
-        [Client.list_archive_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Client.list_archive_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         """
 
     def list_findings(
@@ -239,27 +241,27 @@ class AccessAnalyzerClient:
         sort: SortCriteriaTypeDef = None,
     ) -> ListFindingsResponseTypeDef:
         """
-        [Client.list_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Client.list_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
         """
 
     def start_resource_scan(self, analyzerArn: str, resourceArn: str) -> None:
         """
-        [Client.start_resource_scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Client.start_resource_scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         """
 
     def update_archive_rule(
@@ -270,7 +272,7 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> None:
         """
-        [Client.update_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Client.update_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         """
 
     def update_findings(
@@ -282,7 +284,19 @@ class AccessAnalyzerClient:
         resourceArn: str = None,
     ) -> None:
         """
-        [Client.update_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Client.update_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        """
+
+    def validate_policy(
+        self,
+        policyDocument: str,
+        policyType: Literal["IDENTITY_POLICY", "RESOURCE_POLICY", "SERVICE_CONTROL_POLICY"],
+        locale: Literal["DE", "EN", "ES", "FR", "IT", "JA", "KO", "PT_BR", "ZH_CN", "ZH_TW"] = None,
+        maxResults: int = None,
+        nextToken: str = None,
+    ) -> ValidatePolicyResponseTypeDef:
+        """
+        [Client.validate_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         """
 
     @overload
@@ -290,7 +304,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+        [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
         """
 
     @overload
@@ -298,7 +312,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+        [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
         """
 
     @overload
@@ -306,13 +320,13 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+        [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+        [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
         """
 
     @overload
@@ -320,11 +334,17 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+        [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.27/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
+        """
+        [Paginator.ValidatePolicy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
         """
